@@ -1,7 +1,7 @@
 /*
-    Qalculate    
+    Qalculate (GTK+ UI)
 
-    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna_k@fmgirl.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,6 +17,9 @@
 #define EXPAND_TO_ITER(model, view, iter)		GtkTreePath *path = gtk_tree_model_get_path(model, &iter); \
 							gtk_tree_view_expand_to_path(GTK_TREE_VIEW(view), path); \
 							gtk_tree_path_free(path);
+#define SCROLL_TO_ITER(model, view, iter)		GtkTreePath *path2 = gtk_tree_model_get_path(model, &iter); \
+							gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(view), path2, NULL, FALSE, 0, 0); \
+							gtk_tree_path_free(path2);							
 #define EXPAND_ITER(model, view, iter)			GtkTreePath *path = gtk_tree_model_get_path(model, &iter); \
 							gtk_tree_view_expand_row(GTK_TREE_VIEW(view), path, FALSE); \
 							gtk_tree_path_free(path);							
@@ -50,7 +53,7 @@ enum {
 bool can_display_unicode_string_function(const char *str, void *w);
 void set_unicode_buttons();
 
-GdkPixmap *draw_structure(MathStructure &m, PrintOptions po = default_print_options, InternalPrintStruct ips = top_ips, gint *point_central = NULL, int scaledown = 0);
+cairo_surface_t *draw_structure(MathStructure &m, PrintOptions po = default_print_options, InternalPrintStruct ips = top_ips, gint *point_central = NULL, int scaledown = 0);
 
 void update_status_text();
 
@@ -93,7 +96,7 @@ void on_tDataProperties_selection_changed(GtkTreeSelection *treeselection, gpoin
 void on_tUnitSelector_selection_changed(GtkTreeSelection *treeselection, gpointer user_data);
 void on_tUnitSelectorCategories_selection_changed(GtkTreeSelection *treeselection, gpointer user_data);
 
-void execute_expression(bool force = true, bool do_mathoperation = false, MathOperation op = OPERATION_ADD, MathFunction *f = NULL, bool do_stack = false, size_t stack_index = 0);
+void execute_expression(bool force = true, bool do_mathoperation = false, MathOperation op = OPERATION_ADD, MathFunction *f = NULL, bool do_stack = false, size_t stack_index = 0, string execute_str = string(), string str = string());
 void setResult(Prefix *prefix = NULL, bool update_history = true, bool update_parse = false, bool force = false, string transformation = "", size_t stack_index = 0, bool register_moved = false);
 
 void set_rpn_mode(bool b);
@@ -129,7 +132,6 @@ void update_function_arguments_list(MathFunction *f);
 void on_tNames_selection_changed(GtkTreeSelection *treeselection, gpointer user_data);
 
 void convert_in_wUnits(int toFrom = -1);
-void on_omToUnit_menu_activate(GtkMenuItem *item, gpointer user_data);
 
 void convert_to_unit(GtkMenuItem *w, gpointer user_data);
 
@@ -187,13 +189,12 @@ void edit_names(ExpressionItem *item = NULL, const gchar *namestr = NULL, GtkWid
 extern "C" {
 #endif
 
-#if GTK_MINOR_VERSION >= 3
 gboolean on_completion_match_selected(GtkEntryCompletion *entrycompletion, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data);
 gboolean completion_match_func(GtkEntryCompletion *entrycompletion, const gchar *key, GtkTreeIter *iter, gpointer user_data);
-#endif
 
 void *view_proc(void*);
 void *command_proc(void*);
+void on_message_bar_response(GtkInfoBar *w, gint response_id, gpointer);
 void on_history_populate_popup(GtkTextView *w, GtkMenu *menu, gpointer user_data);
 void on_expression_populate_popup(GtkEntry *w, GtkMenu *menu, gpointer user_data);
 void on_combobox_base_changed(GtkComboBox *w, gpointer user_data);
@@ -201,6 +202,7 @@ void on_combobox_numerical_display_changed(GtkComboBox *w, gpointer user_data);
 void on_expander_keypad_expanded(GObject *o, GParamSpec *param_spec, gpointer user_data);
 void on_expander_history_expanded(GObject *o, GParamSpec *param_spec, gpointer user_data);
 void on_expander_stack_expanded(GObject *o, GParamSpec *param_spec, gpointer user_data);
+void on_expander_convert_expanded(GObject *o, GParamSpec *param_spec, gpointer user_data);
 void on_menu_item_meta_mode_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_meta_mode_save_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_meta_mode_delete_activate(GtkMenuItem *w, gpointer user_data);
@@ -297,6 +299,7 @@ void on_menu_item_export_csv_file_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_convert_to_unit_expression_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_convert_to_base_units_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_convert_to_best_unit_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_set_prefix_activate(GtkMenuItem*, gpointer user_data);
 void on_menu_item_insert_matrix_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_insert_vector_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_enable_variables_activate(GtkMenuItem *w, gpointer user_data);
@@ -316,6 +319,9 @@ void on_menu_item_new_unit_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_rpn_mode_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_rpn_syntax_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_limit_implicit_multiplication_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_adaptive_parsing_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_ignore_whitespace_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_no_special_implicit_multiplication_activate(GtkMenuItem *w, gpointer user_data);
 void fetch_exchange_rates(int timeout);
 void on_menu_item_fetch_exchange_rates_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_save_defs_activate(GtkMenuItem *w, gpointer user_data);
@@ -353,6 +359,7 @@ void on_set_base_radiobutton_input_hexadecimal_toggled(GtkToggleButton *w, gpoin
 void on_set_base_radiobutton_input_other_toggled(GtkToggleButton *w, gpointer user_data);
 void on_set_base_radiobutton_input_roman_toggled(GtkToggleButton *w, gpointer user_data);
 void on_set_base_spinbutton_input_other_value_changed(GtkSpinButton *w, gpointer user_data);
+void convert_number_bases(const gchar *initial_expression);
 void on_menu_item_convert_number_bases_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_periodic_table_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_assumptions_integer_activate(GtkMenuItem *w, gpointer user_data);
@@ -369,12 +376,16 @@ void on_menu_item_assumptions_negative_activate(GtkMenuItem *w, gpointer user_da
 void on_menu_item_assumptions_nonpositive_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_assumptions_unknown_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_assume_nonzero_denominators_activate(GtkMenuItem *w, gpointer user_data);
+void on_popup_menu_item_abort_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_normal_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_engineering_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_purely_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_non_scientific_activate(GtkMenuItem *w, gpointer user_data);
-void on_popup_menu_item_display_prefixes_activate(GtkMenuItem *w, gpointer user_data);
+void on_popup_menu_item_display_no_prefixes_activate(GtkMenuItem *w, gpointer user_data);
+void on_popup_menu_item_display_prefixes_for_selected_units_activate(GtkMenuItem *w, gpointer user_data);
+void on_popup_menu_item_display_prefixes_for_currencies_activate(GtkMenuItem *w, gpointer user_data);
+void on_popup_menu_item_display_prefixes_for_all_units_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_fraction_decimal_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_fraction_decimal_exact_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_fraction_combined_activate(GtkMenuItem *w, gpointer user_data);
@@ -397,7 +408,10 @@ void on_menu_item_display_engineering_activate(GtkMenuItem *w, gpointer user_dat
 void on_menu_item_display_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_display_purely_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_display_non_scientific_activate(GtkMenuItem *w, gpointer user_data);
-void on_menu_item_display_prefixes_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_display_no_prefixes_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_display_prefixes_for_selected_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_display_prefixes_for_currencies_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_display_prefixes_for_all_units_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_indicate_infinite_series_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_show_ending_zeroes_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_round_halfway_to_even_activate(GtkMenuItem *w, gpointer user_data);
@@ -439,14 +453,18 @@ void on_button_deleteregister_clicked(GtkButton *button, gpointer user_data);
 void on_button_clearstack_clicked(GtkButton *button, gpointer user_data);
 void on_stackview_selection_changed(GtkTreeSelection *treeselection, gpointer user_data);
 void on_stackview_item_edited(GtkCellRendererText *renderer, gchar *path, gchar *new_text, gpointer user_data);
+void on_stackview_item_editing_started(GtkCellRenderer *renderer, GtkCellEditable *editable, gchar *path, gpointer user_data);
+void on_stackview_item_editing_canceled(GtkCellRenderer *renderer, gpointer user_data);
 
 void on_unit_edit_entry_name_changed(GtkEditable *editable, gpointer user_data);
-void on_unit_edit_optionmenu_class_changed(GtkOptionMenu *om, gpointer user_data);
+void on_unit_edit_combobox_class_changed(GtkComboBox *om, gpointer user_data);
+void on_unit_edit_combo_system_changed(GtkComboBox *om, gpointer user_data);
 void on_units_button_new_clicked(GtkButton *button, gpointer user_data);
 void on_units_button_edit_clicked(GtkButton *button, gpointer user_data);
 void on_units_button_insert_clicked(GtkButton *button, gpointer user_data);
 void on_units_button_convert_to_clicked(GtkButton *button, gpointer user_data);
 void on_units_button_delete_clicked(GtkButton *button, gpointer user_data);
+void on_units_combobox_to_unit_changed(GtkComboBox *w, gpointer user_data);
 void on_variables_button_new_clicked(GtkButton *button, gpointer user_data);
 void on_variables_button_edit_clicked(GtkButton *button, gpointer user_data);
 void on_variables_button_insert_clicked(GtkButton *button, gpointer user_data);
@@ -463,8 +481,8 @@ void on_datasets_button_close_clicked(GtkButton *button, gpointer user_data);
 void on_function_edit_entry_name_changed(GtkEditable *editable, gpointer user_data);
 void on_variable_edit_entry_name_changed(GtkEditable *editable, gpointer user_data);
 void on_unknown_edit_checkbutton_custom_assumptions_toggled(GtkToggleButton *w, gpointer user_data);
-void on_unknown_edit_optionmenu_type_changed(GtkOptionMenu *om, gpointer user_data);
-void on_unknown_edit_optionmenu_sign_changed(GtkOptionMenu *om, gpointer user_data);
+void on_unknown_edit_combobox_type_changed(GtkComboBox *om, gpointer user_data);
+void on_unknown_edit_combobox_sign_changed(GtkComboBox *om, gpointer user_data);
 
 void on_dataset_edit_entry_name_changed(GtkEditable *editable, gpointer user_data);
 void on_dataset_edit_button_new_property_clicked(GtkButton *button, gpointer user_data);
@@ -500,12 +518,14 @@ void on_decimals_dialog_spinbutton_min_value_changed(GtkSpinButton *w, gpointer
 void on_decimals_dialog_checkbutton_max_toggled(GtkToggleButton *w, gpointer user_data);
 void on_decimals_dialog_checkbutton_min_toggled(GtkToggleButton *w, gpointer user_data);
 
+gboolean on_expression_button_press_event(GtkWidget *w, GdkEventButton *event, gpointer user_data);
+
 gboolean on_resultview_button_press_event(GtkWidget *w, GdkEventButton *event, gpointer user_data);
 gboolean on_resultview_popup_menu(GtkWidget *w, gpointer user_data);
 
 gboolean on_expression_key_press_event(GtkWidget *w, GdkEventKey *event, gpointer user_data);
 
-gboolean on_resultview_expose_event(GtkWidget *w, GdkEventExpose *event, gpointer user_data);
+gboolean on_resultview_draw(GtkWidget *w, cairo_t *cr, gpointer user_data);
 
 gboolean on_tMatrixEdit_key_press_event(GtkWidget *w, GdkEventKey *event, gpointer user_data);
 gboolean on_tMatrixEdit_button_press_event(GtkWidget *w, GdkEventButton *event, gpointer user_data);
@@ -529,10 +549,10 @@ void on_matrix_radiobutton_vector_toggled(GtkToggleButton *w, gpointer user_data
 
 void on_csv_import_radiobutton_matrix_toggled(GtkToggleButton *w, gpointer user_data);
 void on_csv_import_radiobutton_vectors_toggled(GtkToggleButton *w, gpointer user_data);
-void on_csv_import_optionmenu_delimiter_changed(GtkOptionMenu *w, gpointer user_data);
+void on_csv_import_combobox_delimiter_changed(GtkComboBox *w, gpointer user_data);
 void on_csv_import_button_file_clicked(GtkButton *button, gpointer user_data);
 
-void on_csv_export_optionmenu_delimiter_changed(GtkOptionMenu *w, gpointer user_data);
+void on_csv_export_combobox_delimiter_changed(GtkComboBox *w, gpointer user_data);
 void on_csv_export_button_file_clicked(GtkButton *button, gpointer user_data);
 void on_csv_export_radiobutton_current_toggled(GtkToggleButton *w, gpointer user_data);
 void on_csv_export_radiobutton_matrix_toggled(GtkToggleButton *w, gpointer user_data);
@@ -585,13 +605,15 @@ void on_unit_dialog_button_apply_clicked(GtkButton *w, gpointer user_data);
 void on_unit_dialog_button_ok_clicked(GtkButton *w, gpointer user_data);
 void on_unit_dialog_entry_unit_activate(GtkEntry *entry, gpointer user_data);
 
+void convert_from_convert_entry_unit();
+void on_convert_button_convert_clicked(GtkButton *w, gpointer user_data);
+void on_convert_entry_unit_activate(GtkEntry *entry, gpointer user_data);
+
 void on_element_button_clicked(GtkButton *w, gpointer user_data);
 
 void save_accels();
 
-gboolean
-on_menu_key_press (GtkWidget	*widget,
-		    GdkEventKey *event);
+gboolean on_menu_key_press(GtkWidget *widget, GdkEventKey *event);
 
 #ifdef __cplusplus
 }
